diff libpurple/protocols/qq/login_logout.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/login_logout.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/login_logout.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * file login_logout.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -32,9 +32,9 @@
 #define QQ_LOGIN_MODE_AWAY	    0x1e
 #define QQ_LOGIN_MODE_HIDDEN        0x28
 
-void qq_send_packet_request_login_token(GaimConnection *gc);
-void qq_process_request_login_token_reply(guint8 *buf, gint buf_len, GaimConnection *gc);
-void qq_process_login_reply(guint8 *buf, gint buf_len, GaimConnection *gc);
-void qq_send_packet_logout(GaimConnection *gc);
+void qq_send_packet_request_login_token(PurpleConnection *gc);
+void qq_process_request_login_token_reply(guint8 *buf, gint buf_len, PurpleConnection *gc);
+void qq_process_login_reply(guint8 *buf, gint buf_len, PurpleConnection *gc);
+void qq_send_packet_logout(PurpleConnection *gc);
 
 #endif
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.